@@ -207,28 +207,28 @@ static struct button_widget button_widgets[] = {
     { GDK_equal, GDK_KP_Enter, GDK_Return, GDK_equal,      0 }},
 
     {KEY_START_BLOCK,        "start_group",
-    { GDK_SHIFT_MASK, 0 },
-    { GDK_parenleft, 0 }},
+    { 0,             GDK_SHIFT_MASK, 0 },
+    { GDK_parenleft, GDK_parenleft,  0 }},
 
     {KEY_END_BLOCK,          "end_group",
-    { GDK_SHIFT_MASK, 0 },
-    { GDK_parenright, 0 }},
+    { 0,              GDK_SHIFT_MASK, 0 },
+    { GDK_parenright, GDK_parenright, 0 }},
 
     {KEY_ADD,                "add",
-    { GDK_SHIFT_MASK, 0,        0,          0 },
-    { GDK_plus,       GDK_plus, GDK_KP_Add, 0 }},
+    { 0,        GDK_SHIFT_MASK, 0,          0 },
+    { GDK_plus, GDK_plus,       GDK_KP_Add, 0 }},
 
     {KEY_SUBTRACT,           "subtract",
-    { 0,         0,               0,      0 },
-    { GDK_minus, GDK_KP_Subtract, GDK_R4, 0 }},
+    { 0,         GDK_SHIFT_MASK, 0,               0,      0 },
+    { GDK_minus, GDK_minus,      GDK_KP_Subtract, GDK_R4, 0 }},
 
     {KEY_MULTIPLY,           "multiply",
-    { GDK_SHIFT_MASK, 0,               0,      0 },
-    { GDK_asterisk,   GDK_KP_Multiply, GDK_R6, 0 }},
+    { 0,            GDK_SHIFT_MASK, 0,            GDK_SHIFT_MASK, 0,               0,      0 },
+    { GDK_asterisk, GDK_asterisk,   GDK_multiply, GDK_multiply,   GDK_KP_Multiply, GDK_R6, 0 }},
 
     {KEY_DIVIDE,             "divide",
-    { 0,         GDK_SHIFT_MASK, 0,             0,      GDK_SHIFT_MASK, 0 },
-    { GDK_slash, GDK_slash,      GDK_KP_Divide, GDK_R5, GDK_slash,      0 }},
+    { 0,         GDK_SHIFT_MASK, 0,            GDK_SHIFT_MASK, 0,             0,      GDK_SHIFT_MASK, 0 },
+    { GDK_slash, GDK_slash,      GDK_division, GDK_division,   GDK_KP_Divide, GDK_R5, GDK_slash,      0 }},
 
     {KEY_CHANGE_SIGN,        "change_sign_simple",
     { GDK_SHIFT_MASK, 0 },
@@ -452,7 +452,7 @@ struct Xobject {               /* Gtk+/Xlib graphics object. */
     GtkWidget *disp[MAXDISPMODES];     /* Numeric display mode. */
     GtkWidget *trig[MAXTRIGMODES];     /* Trigonometric mode. */
 
-    char *lnp;                    /* Localized numerical point (UTF8 format) */
+    char *shelf;                       /* PUT selection shelf contents. */   
 
     gboolean warn_change_mode;    /* Should we warn user when changing modes? */
     gboolean bitcalculating_mode;
@@ -479,17 +479,17 @@ reset_display(void)
 
     switch (v->syntax) {
         case NPA:
-            v->noparens = 0;
+            v->ltr.noparens = 0;
             MPstr_to_num("0", DEC, v->MPdisp_val);
-            show_display(v->MPdisp_val);
+            display_set_number(v->MPdisp_val);
             clear_undo_history();
             break;
 
         case EXPRS:
             e = get_state();
             MPstr_to_num("0", DEC, e->ans);
-            exp_clear();
-            show_display(e->ans);
+            display_clear(FALSE);
+            display_set_number(e->ans);
             break;
         
         default:
@@ -543,15 +543,15 @@ ui_set_accuracy(int accuracy)
     widget = gtk_bin_get_child(GTK_BIN(GET_WIDGET("acc_item_other")));
     gtk_label_set_markup_with_mnemonic(GTK_LABEL(widget), text);
 
-    desc = g_strdup_printf(ngettext("Set accuracy from 0 to %d numeric places.",
+    desc = g_strdup_printf(ngettext("Set accuracy from 0 to %d numeric place.",
                                     "Set accuracy from 0 to %d numeric places.",
                                     MAXACC),
                            MAXACC);
 
-    /* Translator: This refers to the current accuracy setting */
-    current = g_strdup_printf(ngettext("Currently set to %d places.",
+    /* Translators: This refers to the current accuracy setting */
+    current = g_strdup_printf(ngettext("Currently set to %d place.",
                                        "Currently set to %d places.",
-                                       accuracy),
+                                       accuracy == 1),
                               accuracy);
     tooltip = g_strdup_printf ("%s %s [A]", desc, current);
     gtk_widget_set_tooltip_text (GET_WIDGET("calc_accuracy_button"), tooltip);
@@ -571,7 +571,7 @@ ui_set_accuracy(int accuracy)
     set_int_resource(R_ACCURACY, accuracy);
     
     ui_make_registers();
-    refresh_display(-1);
+    display_refresh(-1);
     
     /* Hide the manual dialog */
     gtk_widget_hide(X->spframe);
@@ -650,7 +650,7 @@ ui_set_numeric_mode(enum base_type mode)
 
 
 void
-ui_set_show_thousands_seperator(gboolean visible)
+ui_set_show_thousands_separator(gboolean visible)
 {
     GtkWidget *menu;
 
@@ -678,12 +678,16 @@ ui_set_show_bitcalculating(gboolean visible)
     gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(menu), visible);
 
     if (visible) {
-        /* Translators: When the bit calculation extension is visible, by 
-         * clicking on any of these individual bits, their value can be 
-         * toggled, causing the displayed integer value to be adjusted 
-         * accordingly.
+        /* Translators: When the bit editor is visible, there will be two
+         * rows of ones and zeroes shown. When the number being displayed in
+         * in the calculator is an integer value, these ones and zeroes will
+         * be sensitive, and they will correspond to the value of each of 
+         * the bits in the displayed integer number. By clicking on any of 
+         * the labels for these ones and zeroes, their value can be toggled
+         * (a one becomes a zero and a zero becomes a one), causing the 
+         * displayed integer value to be adjusted accordingly.
          */
-        ui_set_statusbar(_("Bit calculation extension activated. Click on bit values to toggle them."), "");
+        ui_set_statusbar(_("Bit editor activated. Click on bit values to toggle them."), "");
     } else {
         ui_set_statusbar("", "");
     }
@@ -720,7 +724,7 @@ static char *
 make_hostname()
 {
     Display *dpy = GDK_DISPLAY();
-    char client_hostname[MAXHOSTNAMELEN + 4];
+    char client_hostname[MAXLINE] = "";
     char hostname[MAXHOSTNAMELEN];
     char *display = DisplayString(dpy);
     char *scanner = display;
@@ -741,10 +745,8 @@ make_hostname()
         strcmp(display, "localhost") &&     
         strcmp(display, "unix") &&          
         strcmp(display, "")) {              
-        SPRINTF(client_hostname, " [%s] ", hostname);
-    } else {                                
-        STRCPY(client_hostname, "");        
-    }                                       
+        SNPRINTF(client_hostname, MAXLINE, " [%s] ", hostname);
+    }
 
     *scanner = ':';
     
@@ -769,12 +771,13 @@ ui_set_mode(enum mode_type mode)
         ui_set_base(DEC);
         ui_set_numeric_mode(FIX);
         ui_set_accuracy(DEFAULT_ACCURACY);
-        ui_set_show_thousands_seperator(FALSE);
+        ui_set_show_thousands_separator(FALSE);
         ui_set_show_trailing_zeroes(FALSE);
         ui_make_registers();
 
         /* Reset display */
         do_clear();
+        ui_set_statusbar("", "");
     }
     
     /* Save mode */
@@ -830,10 +833,10 @@ ui_set_mode(enum mode_type mode)
 
     /* Set the title */
     if((hostname = make_hostname())) {
-        SNPRINTF(title, MAXLINE, hostname_titles[mode], hostname);
+        SNPRINTF(title, MAXLINE, gettext(hostname_titles[mode]), hostname);
         g_free(hostname);
     } else {
-        SNPRINTF(title, MAXLINE, titles[mode]);
+        SNPRINTF(title, MAXLINE, gettext(titles[mode]));
     }
     gtk_window_set_title(GTK_WINDOW(X->kframe), title);
 
@@ -864,7 +867,7 @@ ui_set_mode(enum mode_type mode)
 
 
 void 
-ui_set_statusbar(gchar *text, const gchar *imagename)
+ui_set_statusbar(const gchar *text, const gchar *imagename)
 {
     GtkImage *image = GTK_IMAGE(X->status_image);
 
@@ -878,11 +881,11 @@ ui_set_statusbar(gchar *text, const gchar *imagename)
 }
 
 static void
-set_bit_panel()
+set_bit_panel(void)
 {
     int bit_str_len, i, MP1[MP_SIZE], MP2[MP_SIZE];
     int MP[MP_SIZE];
-    char *bit_str, label[3], tmp[MAXLINE];
+    char bit_str[MAXLINE], label[MAXLINE];
 
     switch (v->syntax) {
         case NPA:
@@ -892,14 +895,17 @@ set_bit_panel()
                 int toclear = (v->current == KEY_CLEAR_ENTRY)
                               ? TRUE : FALSE;
 
-                bit_str = make_fixed(MP1, tmp, BIN, MAXLINE, toclear);
+                make_fixed(bit_str, MAXLINE, MP1, BIN, MAXLINE, toclear);
                 bit_str_len = strlen(bit_str);
                 if (bit_str_len <= MAXBITS) {
                     gtk_widget_set_sensitive(X->bit_panel, TRUE);
 
-                    STRCPY(label, " 0");
                     for (i = 0; i < MAXBITS; i++) {
-                        label[1] = (i < bit_str_len) ? bit_str[bit_str_len-i-1] : '0';
+                        if (i < bit_str_len) {
+                            SNPRINTF(label, MAXLINE, " %c", bit_str[bit_str_len-i-1]);
+                        } else {
+                            SNPRINTF(label, MAXLINE, " 0");
+                        }
                         gtk_label_set_text(GTK_LABEL(X->bits[MAXBITS - i - 1]), label);
                     }
 
@@ -909,68 +915,51 @@ set_bit_panel()
             gtk_widget_set_sensitive(X->bit_panel, FALSE);
             break;
 
-          case EXPRS: 
-              {
-                  int ret = usable_num(MP);
-                  if (ret || !is_integer(MP)) {
-                      gtk_widget_set_sensitive(X->bit_panel, FALSE);
-                      return;
-                  }
-                  char *bit_str, label[3], tmp[MAXLINE];
-                  bit_str = make_fixed(MP, tmp, BIN, MAXLINE, FALSE);
-                  bit_str_len = strlen(bit_str);
-                  if (bit_str_len <= MAXBITS) {
-                      gtk_widget_set_sensitive(X->bit_panel, TRUE);
-                      
-                      STRCPY(label, " 0");
-                      for (i = 0; i < MAXBITS; i++) {
-                          label[1] = (i < bit_str_len) ? bit_str[bit_str_len-i-1] : '0';
-                          gtk_label_set_text(GTK_LABEL(X->bits[MAXBITS - i - 1]), label);
-                      }
-                  } else {
-                      gtk_widget_set_sensitive(X->bit_panel, FALSE);
-                  }
-                  
-              }
+        case EXPRS: 
+            if (display_is_usable_number(MP) || !is_integer(MP)) {
+                gtk_widget_set_sensitive(X->bit_panel, FALSE);
+                return;
+            }
+            make_fixed(bit_str, MAXLINE, MP, BIN, MAXLINE, FALSE);
+            bit_str_len = strlen(bit_str);
+            if (bit_str_len <= MAXBITS) {
+                gtk_widget_set_sensitive(X->bit_panel, TRUE);
+                
+                for (i = 0; i < MAXBITS; i++) {
+                    if (i < bit_str_len) {
+                        SNPRINTF(label, MAXLINE, " %c", bit_str[bit_str_len-i-1]);
+                    } else {
+                        SNPRINTF(label, MAXLINE, " 0");
+                    }
+                    gtk_label_set_text(GTK_LABEL(X->bits[MAXBITS - i - 1]), label);
+                }
+            } else {
+                gtk_widget_set_sensitive(X->bit_panel, FALSE);
+            }
             break;
-        
+
         default:
             assert(FALSE);
     }
 }
 
 
-static void
-scroll_right()
-{
-    if (GTK_WIDGET_VISIBLE(
-                   GTK_SCROLLED_WINDOW(X->scrolledwindow)->hscrollbar)) {
-        GtkAdjustment *set;
-
-        set = gtk_scrolled_window_get_hadjustment(
-                                GTK_SCROLLED_WINDOW(X->scrolledwindow));
-        gtk_adjustment_set_value(set, set->upper);
-        gtk_scrolled_window_set_hadjustment(
-                                GTK_SCROLLED_WINDOW(X->scrolledwindow), set);
-    }
-}
-
-
 void
 ui_set_display(char *str, int cursor)
 {
     char localized[MAX_LOCALIZED];
     GtkTextIter iter;
+    GtkAdjustment *adj;
 
     if (str == NULL || str[0] == '\0') {
         str = " ";
     } else {
-        if (v->noparens == 0) {
-            localize_number(localized, str);
+        if (v->syntax == EXPRS || (v->syntax == NPA && v->ltr.noparens == 0)) {
+            localize_expression(localized, str, MAX_LOCALIZED, &cursor);
             str = localized;
         }
     }
-    
+
     gtk_text_buffer_set_text(X->display_buffer, str, -1);
     
     if (cursor < 0) {
@@ -980,8 +969,11 @@ ui_set_display(char *str, int cursor)
     }
     gtk_text_buffer_place_cursor(X->display_buffer, &iter);
     
+    /* Align to the right */
     if (cursor < 0) {
-        scroll_right();
+        adj = gtk_scrolled_window_get_hadjustment(
+                 GTK_SCROLLED_WINDOW(X->scrolledwindow));
+        gtk_adjustment_set_value(adj, adj->upper - adj->page_size);
     }
 }
 
@@ -1050,17 +1042,6 @@ ui_beep()
 }
 
 
-char *
-ui_get_localized_numeric_point(void)
-{
-    const char *decimal_point;
-
-    decimal_point = localeconv()->decimal_point;
-
-    return (g_locale_to_utf8(decimal_point, -1, NULL, NULL, NULL));
-}
-
-
 void
 ui_set_base(enum base_type base)
 {
@@ -1251,7 +1232,7 @@ aframe_response_cb(GtkWidget *dialog, gint response_id)
         ch = (char *) gtk_entry_get_text(GTK_ENTRY(X->aframe_ch));
         val = ch[0];
         mpcim(&val, v->MPdisp_val);
-        show_display(v->MPdisp_val);
+        display_set_number(v->MPdisp_val);
     }
     
     gtk_widget_hide(dialog);
@@ -1317,11 +1298,25 @@ static void do_button(int function, int arg)
 {
     switch (v->syntax) {
         case NPA:
-            process_item(&buttons[function], arg);
+            v->current = buttons[function].id;
+
+            if (v->error) {
+                /* Must press a valid key first. */
+                if (v->current != KEY_CLEAR) {
+                    return;
+                }
+                ui_set_error_state(FALSE);
+            }
+    
+            if (v->ltr.noparens > 0) {
+                do_paren();
+                return;
+            }
+
+            buttons[function].func(arg);
             set_bit_panel();
-            if (v->new_input && v->dtype == FIX) {
-                STRNCPY(v->fnum, v->display, MAX_DIGITS - 1);
-                ui_set_display(v->fnum, -1);
+            if (v->ltr.new_input && v->dtype == FIX) {
+                display_set_string(v->display);
             }
             break;
 
@@ -1466,13 +1461,14 @@ exchange_menu_cb(GtkMenuItem *menu)
 static void
 update_constants_menu(void)
 {
-    char mline[MAXLINE];
+    char mline[MAXLINE], value[MAXLINE];
     int i;
 
     for (i = 0; i < MAX_CONSTANTS; i++) {
+        make_number(value, MAXLINE, v->MPcon_vals[i], DEC, TRUE);
         SNPRINTF(mline, MAXLINE, 
                  "<span weight=\"bold\">%s_%1d:</span> %s [%s]", _("C"), i, 
-                 make_number(v->MPcon_vals[i], DEC, TRUE), 
+                 value, 
                  v->con_names[i]);
         gtk_label_set_markup_with_mnemonic(GTK_LABEL(X->constant_menu_labels[i]), mline);
     }
@@ -1582,15 +1578,19 @@ create_constants_model()
     gint i = 0;
     GtkListStore *model;
     GtkTreeIter iter;
+    char constant[MAXLINE];
 
     model = gtk_list_store_new(NUM_COLUMNS, G_TYPE_INT, G_TYPE_STRING,
                                G_TYPE_STRING, G_TYPE_BOOLEAN);   
     for (i = 0; i < MAX_CONSTANTS; i++) {
         gtk_list_store_append(model, &iter);
         
+        make_number(constant, MAXLINE, v->MPcon_vals[i], DEC, TRUE);
         gtk_list_store_set(model, &iter,
                            COLUMN_NUMBER, i,
                            COLUMN_EDITABLE, TRUE,
+                           COLUMN_VALUE, g_strdup(constant),
+                           COLUMN_DESCRIPTION, g_strdup(v->con_names[i]),
                            -1);
     }
 
@@ -1614,6 +1614,8 @@ create_functions_model()
         gtk_list_store_set(model, &iter,
                            COLUMN_NUMBER, i,
                            COLUMN_EDITABLE, TRUE,
+                           COLUMN_VALUE, g_strdup(v->fun_vals[i]),
+                           COLUMN_DESCRIPTION, g_strdup(v->fun_names[i]),
                            -1);
     }
 
@@ -1624,15 +1626,16 @@ create_functions_model()
 void
 ui_make_registers()            /* Calculate memory register frame values. */
 {
-    char *mval, key[MAXLINE];
+    char mval[MAXLINE], key[MAXLINE], value[MAXLINE];
     int n;
 
     for (n = 0; n < MAX_REGISTERS; n++) {
-        mval = make_number(v->MPmvals[n], v->base, TRUE);
+        make_number(mval, MAXLINE, v->MPmvals[n], v->base, TRUE);
         gtk_entry_set_width_chars(GTK_ENTRY(X->regs[n]), strlen(mval));
         gtk_entry_set_text(GTK_ENTRY(X->regs[n]), mval);
         SNPRINTF(key, MAXLINE, "register%d", n);
-        set_resource(key, mval);
+        make_number(value, MAXLINE, v->MPmvals[n], DEC, TRUE);
+        set_resource(key, value);
     }
 }
 
@@ -1721,7 +1724,7 @@ bit_toggle_cb(GtkWidget *event_box, GdkEventButton *event)
             MPstr_to_num(v->display, v->base, MP1);
             break;
         case EXPRS: {
-            int ret = usable_num(e->ans);
+            int ret = display_is_usable_number(e->ans);
             assert(!ret);
             mpstr(e->ans, MP1);
         }
@@ -1745,18 +1748,18 @@ bit_toggle_cb(GtkWidget *event_box, GdkEventButton *event)
     switch (v->syntax) {
         case NPA:
             mpcdm(&number, v->MPdisp_val);
-            show_display(v->MPdisp_val);
+            display_set_number(v->MPdisp_val);
             break;
         case EXPRS:
             mpcdm(&number, e->ans);
-            exp_replace("Ans");
-            refresh_display(-1);
+            display_set_string("Ans");
+            display_refresh(-1);
             break;
         default:
             assert(FALSE);
     }
 
-    v->toclear = 0;
+    v->ltr.toclear = 0;
     return (TRUE);
 }
 
@@ -1805,14 +1808,15 @@ set_menubar_tooltip(gchar *menu_name)
 static void
 update_memory_menus()
 {
-    char mstr[MAXLINE];
+    char mstr[MAXLINE], value[MAXLINE];
     int i;
 
     for (i = 0; i < MAX_REGISTERS; i++) {
+        make_number(value, MAXLINE, v->MPmvals[i], v->base, TRUE);
         SNPRINTF(mstr, MAXLINE, "<span weight=\"bold\">%s_%d:</span>    %s",
         /* translators: R is the short form of register used inter alia
         in popup menus */
-                _("R"), i, make_number(v->MPmvals[i], v->base, TRUE));
+                _("R"), i, value);
         gtk_label_set_markup_with_mnemonic(GTK_LABEL(X->memory_store_labels[i]), mstr);
         gtk_label_set_markup_with_mnemonic(GTK_LABEL(X->memory_recall_labels[i]), mstr);
         gtk_label_set_markup_with_mnemonic(GTK_LABEL(X->memory_exchange_labels[i]), mstr);
@@ -1853,13 +1857,13 @@ get_display()              /* The Copy function key has been pressed. */
         string = ui_get_display();
     }
 
-    if (v->shelf != NULL) {
-        free(v->shelf);
+    if (X->shelf != NULL) {
+        free(X->shelf);
     }
-    v->shelf = g_locale_from_utf8(string, strlen(string), NULL, NULL, NULL);
+    X->shelf = g_locale_from_utf8(string, strlen(string), NULL, NULL, NULL);
     g_free(string);
 
-    gtk_clipboard_set_text(gtk_clipboard_get(X->clipboard_atom), v->shelf, -1);
+    gtk_clipboard_set_text(gtk_clipboard_get(X->clipboard_atom), X->shelf, -1);
 }
 
 
@@ -1895,7 +1899,7 @@ check_for_localized_numeric_point(int keyval)
 
     outbuf[g_unichar_to_utf8(ch, outbuf)] = '\0';
 
-    return (strcmp(outbuf, X->lnp) == 0);
+    return (strcmp(outbuf, v->radix) == 0);
 }
 
 
@@ -2176,7 +2180,7 @@ get_proc(GtkClipboard *clipboard, const gchar *buffer, gpointer data)
         case NPA:
             ret = lr_parse((char *) text, v->MPdisp_val);
             if (!ret) {
-                show_display(v->MPdisp_val);
+                display_set_number(v->MPdisp_val);
             } else {
                 ui_set_statusbar(_("Clipboard contained malformed calculation"),
                                  "gtk-dialog-error");
@@ -2184,8 +2188,8 @@ get_proc(GtkClipboard *clipboard, const gchar *buffer, gpointer data)
             break;
     
         case EXPRS:
-            exp_insert((char *) text, get_cursor()); // FIXME: Move out of gtk.c
-            refresh_display(-1);
+            display_insert((char *) text, get_cursor()); // FIXME: Move out of gtk.c
+            display_refresh(-1);
             break;
     
         default:
@@ -2238,7 +2242,7 @@ static void
 redo_cb(GtkWidget *widget)
 {
     perform_redo();
-    refresh_display(-1);
+    display_refresh(-1);
 }
 
 
@@ -2441,16 +2445,6 @@ spframe_activate_cb(GtkWidget *spin)
 }
 
 
-/*ARGSUSED*/
-void
-trig_cb(GtkWidget *widget)
-{
-    if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget)))
-        do_trigtype((enum trig_type) g_object_get_data(G_OBJECT(widget),
-                                                       "trig_mode"));
-}
-
-
 /*ARGSUSED*/
 static void
 show_thousands_separator_cb(GtkWidget *widget)
@@ -2458,7 +2452,7 @@ show_thousands_separator_cb(GtkWidget *widget)
     gboolean visible;
     
     visible = gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(widget));
-    ui_set_show_thousands_seperator(visible);
+    ui_set_show_thousands_separator(visible);
 }
 
 
@@ -2546,7 +2540,6 @@ create_kframe()
     CONNECT_SIGNAL(mode_radio_cb);
     CONNECT_SIGNAL(inv_cb);
     CONNECT_SIGNAL(hyp_cb);
-    CONNECT_SIGNAL(trig_cb);
     CONNECT_SIGNAL(base_cb);
     CONNECT_SIGNAL(disp_cb);
     CONNECT_SIGNAL(quit_cb);
@@ -2845,7 +2838,7 @@ read_cfdefs()        /* Read constant/function definitions. */
         get_constant(n);
     }
     for (n = 0; n < MAX_FUNCTIONS; n++) {
-        STRCPY(v->fun_vals[n], "");    /* Initially empty function strings. */
+        STRNCPY(v->fun_vals[n], "", MAXLINE - 1);    /* Initially empty function strings. */
         get_function(n);
     }
 }
@@ -2858,7 +2851,7 @@ ui_init(int *argc, char ***argv)
         
     gtk_init(argc, argv);
 
-    X->lnp = ui_get_localized_numeric_point();
+    X->shelf      = NULL;      /* No selection for shelf initially. */
 
     gtk_rc_get_default_files();
 
@@ -2870,7 +2863,7 @@ ui_init(int *argc, char ***argv)
 
 
 void
-ui_load()
+ui_load(void)
 {
     int boolval;
     char *resource, text[MAXLINE];
@@ -2886,7 +2879,7 @@ ui_load()
     resource = get_resource(R_BITCALC);
     show_bit = resource != NULL && strcmp(resource, Rcstr[0]) != 0;
 
-    ui_set_show_thousands_seperator(v->show_tsep);
+    ui_set_show_thousands_separator(v->show_tsep);
     ui_set_show_trailing_zeroes(v->show_zeroes);
     ui_set_show_bitcalculating(show_bit);
     
@@ -2919,7 +2912,7 @@ ui_load()
 }
 
 void
-ui_start()
+ui_start(void)
 {
     X->warn_change_mode = TRUE; // FIXME: Load from GConf
     
