@@ -24,9 +24,9 @@
 
 #include "calctool.h"
 
-void ui_init();
-void ui_load();
-void ui_start();
+void ui_init(int *argc, char ***argv);
+void ui_load(void);
+void ui_start(void);
 
 void ui_make_registers(void);
 void ui_set_undo_enabled(gboolean, gboolean);
@@ -43,14 +43,13 @@ void ui_set_inverse_state(gboolean);
 void ui_set_hyperbolic_state(gboolean);
 void ui_set_trigonometric_mode(enum trig_type);
 void ui_set_numeric_mode(enum base_type);
-void ui_set_show_thousands_seperator(gboolean);
+void ui_set_show_thousands_separator(gboolean);
 void ui_set_show_bitcalculating(gboolean);
 void ui_set_show_trailing_zeroes(gboolean);
 
 void ui_set_error_state(gboolean);
-void ui_set_statusbar(gchar *, const gchar *);
+void ui_set_statusbar(const gchar *, const gchar *);
 
 void ui_beep(void);
-char *ui_get_localized_numeric_point(void);
 
 #endif /* UI_H */
